HAWK: Higgs Attached to WeaK bosons
===================================

HAWK, Version 3.0.2, released on 13th October 2022

HAWK can be downloaded from http://hawk.hepforge.org/

----

HAWK has been tested under

    Operating Systems:
                     Various Linux systems

    Compilers:
                     GNU Fortran (GCC)
                     Intel Fortran Compiler
                     Openmpi
    Language:
                     Fortran 77/95/C

----

Changelog
---------

Summary of changes in HAWK, Version 2.0.1:

January 20, 2015:

    * version 2.0.1 is made compatible with LHAPDF-6.1.5, no other changes

Summary of changes in HAWK, Version 2.0.2:

January 13, 2016:

    * version 2.0.2 allows for calculation of inclusive cross sections also in all
      WH/ZH channels, including photon-induced contributions.  Bug in the output
      of the relative corrections from incoming photons is fixed.

Summary of changes in HAWK, Version 3.0.0:

May 3, 2019:

    * Recola1/Recola2 + Collier support

Summary of changes in HAWK, Version 3.0.1:

September 3, 2021

    * Wrong sign in implementation of CP-violating anomalous HVV coupling fixed.

Summary of changes in HAWK, Version 3.0.2:

October 13, 2022

    * Support for dynamical renormalization and factorization scales added.

----

AUTHORS
-------

    Ansgar Denner, University of Wurzburg, Germany (denner@physik.uni-wuerzburg.de)
    Stefan Dittmaier, University of Freiburg, Germany (stefan.dittmaier@physik.uni-freiburg.de)
    Stefan Kallweit, Universita di Milano-Bicocca, Italy (stefan.kallweit@unimib.it)
    Jean-Nicolas Lang, University of Zurich, Switzerland (jlang@physik.uzh.ch)
    Alexander Muck, RWTH Aachen, Germany (mueck@physik.rwth-aachen.de)

ACKNOWLEDGEMENTS
----------------

We thank Mariano Ciccolini for performing an independent calculation
for vector-boson fusion to verify the correctness of parts of the code.


BRIEF DESCRIPTION
-----------------

HAWK is a Monte Carlo integrator for
  * VBFH:   pp/ppbar -> H + 2jets,
  * WH/ZH:  pp/ppbar -> HW(->ln), HZ(->ll/nn)

It includes:

    * NLO QCD and electroweak (EW) corrections
    * all weak-boson fusion and quark-antiquark annihilation diagrams for VBFH
    * all interferences at LO and NLO
    * contributions from incoming photons
    * leading heavy-Higgs-boson effects at two-loop order (only VBFH)
    * contributions of b-quark PDFs at LO
    * an interface to LHAPDF
    * decay of the Higgs boson into a pair of gauge singlets (only VBFH)
    * options for using an off-shell Higgs propagator
    * pp and p pbar collisions
    * effects of anomalous HZZ/HWW couplings
    * an interface to Recola/Recola2 allowing for
      neutral Higgs production in the Two-Higgs-doublet Model and
      the Higgs-singlet extension of the Standard Model

The present version does not include:

    * Higgs-boson decays beyond simple two-body kinematics
    * production of unweighted events
    * interface to parton showers
    * contributions from gg initial states


PUBLICATIONS:

[1] M. Ciccolini, A. Denner, S. Dittmaier,
Strong and electroweak corrections to the production of Higgs + 2jets via weak interactions at the LHC,
Phys. Rev. Lett. 99 (2007) 161803 [arXiv:0707.0381[hep-ph]];

[2] M. Ciccolini, A. Denner, S. Dittmaier,
Electroweak and QCD corrections to Higgs production via vector-boson fusion at the LHC,
Phys. Rev. D77 (2008) 013002 [arXiv:0710.4749 [hep-ph]];

[3] A. Denner, S. Dittmaier, S. Kallweit, A. Muck
Electroweak corrections to Higgs-strahlung off W/Z bosons at the Tevatron and the LHC with HAWK
JHEP 07 (2012) 076 [arXiv:1112.5142 [hep-ph]];

[4] A. Denner, S. Dittmaier, J.-N. Lang
Renormalization of mixing angles
JHEP 1811 (2018) 104 [arXiv:1808.03466 [hep-ph]].


INSTALLATION
------------

Gunzip and untar HAWK-3.0.2.tar.gz:

    tar -xf HAWK-3.0.2.tar.gz

The source files are contained in the HAWK-3.0.2/src directory.
The directory HAWK-3.0.2/sampleruns contains results of sample runs.
The directories HAWK-3.0.2/bin, HAWK-3.0.2/build
are for the executable, build files, respectively.

For usage of up-to-date parton distributions functions (PDFs), an
interface to the LHAPDF library is provided. The LHAPDF library is
not part of the HAWK distribution. In order to use LHAPDF,
a working LHAPDF installation has to be available. The information
on the LHAPDF installation needs to be provided via the LHAPDF executable
'lhapdf-config' which is part of the LHAPDF installation. To make
the executable 'lhapdf-config' available, you have the following options:
-copy it to the HAWK directory (or build)
-include its directory to the PATH variable of your shell.

It is possible to compile HAWK without LHAPDF, however, for usage without
LHAPDF, only the tables for three PDF sets (MRST2004QED, CTEQ6L1 and CTEQ6M)
are included in the directory HAWK/PDFs.

## COMPILATION

In order to compile the stand-alone version of HAWK with LHAPDF (without RECOLA) execute:

    cd build
    cmake .. -DLHAPDF=On
    make install

The executable will be installed to the bin folder inside the hawk sources.
Run with ``make -j install`` to compile in parallel.

In order to compile HAWK with Recola1 + LHAPDF run:

    cd build
    cmake .. -DRECOLA1=On -DLHAPDF=On
    make install

In order to compile HAWK with Recola2 + LHAPDF run:

    cd build
    cmake .. -DRECOLA2=On -Dmodel=<model> -DLHAPDF=On
    make install

where <model> can take the values: SM, SM_BFM, HS, HS_BFM, THDM, THDM_BFM.

.. note::

    Note that the CMake options are cached and switching configuration
    requires to explicitly set options to On/Off. For instance,
    compiling Recola1 prior to Recola2, requires to set -DRECOLA1=Off for
    the configuration of Recola2.

For handling multiple models and setups it is recommended to configure and
install HAWK to specific paths. For instance, in order to set up HAWK with the HS
and HS_BFM model invoke

    cd build
    cmake .. -DRECOLA2=On -Dmodel=HS -DLHAPDF=On -DCMAKE_INSTALL_PREFIX=../HAWK_HS
    make install
    cmake .. -Dmodel=HS_BFM -DCMAKE_INSTALL_PREFIX=../HAWK_HS_BFM
    make install

.. note::

    When using Recola the before-mentioned commands will automatically download
    a suited version. HAWK can be linked to a local version of Recola/Collier by
    disabling the download step via the CMake option -DDOWNLOAD=Off and setting
    the environment variable "RECOLA_PATH=,COLLIER_PATH=" to where librecola.so
    (or recolaConfig.cmake)/libcollier.so (or collierConfig.cmake) is located,
    in addition to specifying the major recola version via -DRECOLA1/-DRECOLA2.

.. note::

    Changing the default Fortran compiler is steered with
    -DCMAKE_Fortran_COMPILER. Reconfiguration with a different Fortran compiler
    is only possible if the build has not been started or by removing the build
    directory.

.. note::

    For use in the SM we recommend using HAWK without Recola which
    is expected to perform the best.

## Usage

For executions "hawk-3.0.2" needs an inputfile from the standard input
(see however the remarks for parallel execution using mpi below).
When using LHAPDF, the relevant files for the PDFs should be
in the directory PDFsets of LHAPDF.
When using the included PDF sets, the corresponding table files
("qed6-10gridp.dat" for MRST2004QED or "cteq6m.tbl",
"cteq6l1.tbl" for CTEQ6) must be copied from the subdirectory
HAWK-3.0.2/PDFs into the working directory, where hawk-3.0.2 is
executed.

The program can be executed using ./hawk-3.0.2 < inputfile > outputfile.
If an output file is specified in the inputfile it will be used.

#### INPUT

All input should be delivered via the inputfile. This has to be specified
via standard input, otherwise HAWK does not start.
Its general format can be seen from the default inputfile "input_default"
in the directory HAWK-3.0.2/sampleruns and the inputfiles of the subdirectories.
While the sample input files specify all relevant parameters, it is
sufficient to specify those values that differ from the default.

Do not forget the "d0" after "double precision" quantities.

The default input of HAWK is taken from CERN-2017-002-M.

In the following we present the content of the file "input_default" with
additional comments added. The specified values correspond to the default.


#### global parameters

Name of outputfile if the variable is blank output is written to standard output
  * outputfile =' '              ! output to standard output
  * outputfile ='output_default' ! output to file

Select the process to be calculated:

    selprocess = 0:     Hjj,     p p -> jet jet H,    (VBFH)
    selprocess = 1:     Hln,     p p -> l+  nu  H,    (W+H)
    selprocess = 2:     Hnl,     p p -> nu~ l-  H,    (W-H)
    selprocess = 3:     Hll,     p p -> l+  l-  H,    (ZH)
    selprocess = 4:     Hnn,     p p -> nu~ nu  H,    (ZH)

.. note::

    A change of this flag sets all options and cuts to their defaults. They can
    be changed thereafter.

.. note::

    The number of weighted events should be at least 10^7 to guarantee that the
    multi-channel integration yields reliable estimates. For histograms more
    events should be used. For the published distributions we used 10^9.

Set the number of events:

    nevents = 10000000

Set the cms energy in pp/ppbar system in GeV:

    energy = 14000d0

Set the initial state:

    sppbar=0     p p initial state
    sppbar=1     p pbar initial state (p in +z direction)


# Input parameters
## SM parameters

    gf=0.11663787d-04            ! Fermi constant
    mz=91.1876d0                 ! Z-boson mass
    gz=2.4952d0                  ! Z-boson width
    mw=80.385d0                  ! W-boson mass
    gw=2.085d0                   ! W-boson width
    mmu=0.1056583715d0           ! muon mass
    mt=172.5d0                   ! top-quark mass
    mh=125.0d0                   ! Higgs mass
    gh=4.088d-3                  ! Higgs width
    sinthetac=0.225d0            ! sine of the Cabibbo angle
                                 ! the CKM matrix is always treated as real and
                                 ! block-diagonal, i.e. without mixing between
                                 ! 1st/2nd and 3rd generation.

.. note::

    The program reads the on-shell masses and widths and translates them
    internally to the pole masses and widths. These are then used in propagators
    and the complex weak mixing angle and other couplings. The output provides
    the pole masses, not the input masses!

.. note::

    The masses of the light fermions appear internally, but the results are
    practically independent of the specific values in the alpha_GF scheme used.
    Only for bare leptons in the final state their mass becomes relevant. Here
    HAWK uses the input value for the muon mass mmu.

.. note::

    A non-diagonal CKM matrix is not supported for VBFH with Recola.


Recombination and cuts
----------------------


# VBFH

Recombination of quarks and gluons according to the kt algorithm of G. C. Blazey
et al., hep-ex/0005012 (variants see under [ktpower](#ktpower) )

# ktpower

    ktpower=1                    ! kt algorithm (1), anti-kt algorithm (-1),
                                 ! Cambridge-Aachen (0)
    dparameter=0.4d0             ! D parameter of jet algorithm
    etacut(parton)=5.0d0         ! pseudorapidity cut on partons in jet algorithm
    dgammaparameter=0.1d0        ! D parameter of lepton-photon recombination



# WH/ZH

Recombination of charged leptons and a bremsstrahlung photon if:

    deltaR(lep,phot) < dgammaparameter

If this holds for more than one lepton, the one with the smaller dR is
recombined. The recombined particle is treated as a lepton.

Leptons can be isolated from collinear photons as described in 0802.1405
[hep-ph] using:

    sbarelep=1 ! leptons are isolated from collinear photons

As this option is considered to make sense only in case of muons, the lepton
mass in the splittings is automatically set to the muon mass.

No such isolation is applied with:

    sbarelep=0

which is the recommended option to investigate the electron case.

.. note::

    For other recombination schemes the subroutines
    "vbfh_recombination" in "vbfh_public.F" or
    "whzh_recombination" in "whzh_public.F" must be modified.
    If this is required, please contact the authors.


Standard cuts
-------------

    scuts=0

no cuts  (only useful for total cross section).

    scuts=-1

no predefined cuts (all cuts to be set by user).

## VBFH

    scuts=1

the standard cuts as defined in references [1,2] given above (see also T. Figy
and D. Zeppenfeld, Phys. Lett. B 591 (2004) 297 [hep-ph/0403297]) Jets are
ordered according to pt of jets.

    scuts=2

Standard cuts as defined in references [1,2] given above (see also T. Figy and D.
Zeppenfeld, Phys. Lett. B 591 (2004) 297 [hep-ph/0403297]) jets are ordered
according to energy of jets.

### WH/ZH

    scuts=1

Standard cuts for detected leptons as defined in reference [3] given above.

    scuts=2

Standard cuts for undetected leptons as defined in reference [3] given above.


.. note::

    These options set various cuts to their default values. They can be changed
    thereafter.

.. note::

    For other cut schemes the subroutines "applycut" or "applyhiggscut" in
    "public.F" or "applyjetcut" in "vbfh_public.F" or "applylepcut" or
    "applylephiggscut" in "whzh_public.F" must be modified.
    If this is required, please contact the authors.


## standard cut parameters

The following standard cut parameters can be set after choosing scuts:

### standard cuts for VBFH (i.e. selprocess = 0)

    ptcut(jet1)=20d0             ! lower pt cut on jet 1 (leading jet)
    ptcut(jet2)=20d0             ! lower pt cut on jet 2 (subleading jet)
    ycut(jet1)=4.5d0             ! upper |y| cut on jet 1
    ycut(jet2)=4.5d0             ! upper |y| cut on jet 2
    dycut(jet,jet)=4.0d0         ! lower delta y cut between jets 1 and 2
    hemispherecut=1              ! y(jet1)*y(jet2) < 0
    ptmax(jet1)=1d30             ! upper pt cut on jet 1
    ptmax(jet2)=1d30             ! upper pt cut on jet 2
    ptmax(jet3)=1d30             ! upper pt cut on jet 3
    ymin(jet1)=0d0               ! lower |y| cut on jet 1
    ymin(jet2)=0d0               ! lower |y| cut on jet 2
    ymin(jet3)=0d0               ! lower |y| cut on jet 3
    ptcut(visible)=0d0           ! lower cut on |pt_jet1+pt_jet2+pt_H| (vector sum)
    ptmax(visible)=1d30          ! upper cut on |pt_jet1+pt_jet2+pt_H| (vector sum)
    mlcut(jet,jet)=0d0           ! lower cut on invariant mass of pair of jets 1 and 2
    mucut(jet,jet)=1d30          ! upper cut on invariant mass of pair of jets 1 and 2
    dphicut(jet1,higgs)=0d0      ! lower cut on azimuth between jet 1 and Higgs
    dphicut(jet2,higgs)=0d0      ! lower cut on azimuth between jet 2 and Higgs
    ptcut(higgs)=0d0             ! lower pt cut on Higgs
    ycut(higgs)=1d10             ! upper |y| cut on Higgs
    ecut(higgs)=0d0              ! lower energy cut on Higgs
    mlcut(higgs)=1d-2            ! lower cut on the invariant mass of Higgs
    mucut(higgs)=1d30            ! upper cut on the invariant mass of Higgs

    hemispherecut=0   ! no hemispherecut
    hemispherecut=1   ! y(jet1)*y(jet2) < 0 required for jets 1 and 2

In order to implement a jet veto, ptmax and ymin can be used in combination to
define final states without detectable jets, where a "detectable jet" fulfils
pt(jet) > ptmax(jet) and |y(jet)| < ymin(jet).
The cuts for jet1 apply to all jets, those for jet2 for all but the leading
jet, those for jet3 only to the third jet.
Set ptmax(jet1/2/3)=1d30 and/or ymin(jet1/2/3)=0d0 to switch off these cuts.

### standard cuts for WH/ZH (i.e. selprocess = 1, 2, 3, 4)

for scuts=1:

    ptcut(lep)=20d0              ! lower pt cut on leptons
    ycut(lep)=2.5d0              ! upper |y| cut on leptons
    ptmax(lep)=1d10              ! upper pt cut on leptons
    ymin(lep)=0d0                ! lower |y| cut on leptons

for scuts=2:

    ptcut(lep)=0d0               ! lower pt cut on leptons
    ycut(lep)=1d10               ! upper |y| cut on leptons
    ptmax(lep)=20d0              ! upper pt cut on leptons
    ymin(lep)=2.5d0              ! lower |y| cut on leptons

for scuts=1 and scuts=2:

    ptcut(V)=190d0               ! lower pt cut on V
    ptcut(miss)=25d0             ! lower cut on missing-pt (pt of neutrino(s))
    drcut(lep,lep)=0d0           ! lower cut on dR between leptons
    drcut(jet,lep)=0d0           ! lower cut on dR between lepton and jet
    mlcut(lep,lep)=0d0           ! lower cut on invariant mass between leptons
    mucut(lep,lep)=1d10          ! upper cut on invariant mass between leptons
    ecut(lep)=0d0                ! lower energy cut on leptons
    ptcut(higgs)=200d0           ! lower pt cut on Higgs
    ycut(higgs)=1d10             ! upper |y| cut on Higgs
    ecut(higgs)=0d0              ! lower energy cut on Higgs

In analogy to a jet veto ptmax and ymin are used in combination to define
final states without detectable leptons, where a detectable lepton fulfils:

    pt(lep) > ptmax(lep)

and

    |y(lep)| < ymin(lep).

Set

    ptmax(lep)=1d10

and/or

    ymin(lep)=0d0

to switch off this cut.

# off-shell Higgs boson, decays and corresponding cuts

    shtr=0     ! on-shell Higgs boson (default)
    shtr=1     ! off-shell Higgs boson
    shtr=2     ! off-shell Higgs boson decaying into a pair of singlets (only for VBFH)

.. note::

    For shtr=1 the external Higgs boson is off-shell and the resonance is
    treated according to the flag shbw (see below) for shtr=2 additionally an
    isotropic Higgs decay into a pair of scalar singlets is included. This can
    be used to mimic any two-body decay, e.g. the decay into photons.

.. note::

    For shtr=1 or 2 the width of the Higgs boson has to be given as input or the
    width can be calculated internally (see gh and sgh below).  for shtr=2 in
    addition the branching ratio for the decay into singlets has to be given

.. note::

    For an off-shell Higgs boson the electroweak corrections are calculated
    after an on-shell projection of the momenta

.. note::

    An off-shell Higgs boson is not supported with Recola.

For an off-shell Higgs boson (shtr=1 or 2) the following prescription
is used for the Higgs resonance:

    shbw=0     ! standard Breit-Wigner with mass mh and (constant) width gh
    shbw=1     ! off-shell propagator according to arXiV:1107.0683, eq. (4.6)
    sgh=0      ! use Higgs width as specified in input by gh
    sgh=1      ! gh is set for the input Higgs mass using an interpolation
               ! of the results in arXiv:1101.0593 [hep-ph]
               ! (based on a routine of G. Passarino)
    sgh=2      ! gh is calculated according to the complex-mass scheme
               ! (using cpHTO11.f by G. Passarino)
               ! for sgh=1 or sgh=2 the input value gh is not used

.. note:

    for shbw=1, sgh=0 is not allowed


Width of the Higgs boson and branching ratio for the decay into singlets
(for shtr=2). Hbr simply rescales the complete cross section.

    gh=0.00421d0                 ! Higgs width (for MH=126 GeV)
    Hbr=1d0                      ! branching ratio for Higgs decay into singlets

# cut parameters for cuts on Higgs decay products (singlets)

    ptcut(decp)=0d0              ! lower pt cut on Higgs decay products
    ycut(decp)=1d10              ! upper |y| cut on Higgs decay products

    higgsbetweenjets=0           ! min(y(jet1),y(jet2))<y(decp)<max(y(jet2),y(jet2))


# PDF set

    spdf=99                      ! parton distributions via LHAPDF  (default)
                                 ! requires to specify a PDF set via
                                 ! 'pdfname' or 'pdfpath'
    spdf=1                       ! MRST2004 parton distributions (spdf=1)
    spdf=11                      ! CTEQ6M parton distributions  (spdf=11)
    spdf=14                      ! CTEQ6L1 parton distributions (spdf=14)

.. note:

    Photon PDFs are included only for spdf=1 or for spdf=99 if appropriate
    parton distributions are used.  This is the case for the default PDF set
    NNPDF31_nlo_as_0118_luxqed.  For other PDFs only quark and gluon PDF sets
    are taken into account.

    pdfname=NNPDF31_nlo_as_0118_luxqed ! name of PDF set in LHAPDF
    pdfpath='/.../lhapdf-6.2.1/share/lhapdf/PDFsets/NNPDF31_nlo_as_0118_luxqed'

Alternative ways to specify the PDF set for the LHAPDF interface
the chosen PDF set must be available within the LHAPDF installation

  * pdfname:  only the LHAPDF name of the PDF set is needed.
  * pdfpath:  the name of the the PDF set including the full path has to be
              provided; note the apostrophes around the pdfpath!

    pdfmember=0                  ! central value PDF set

For uncertainty calculations the values allowed by the PDF set can be used

    pdfmemberfrom=1              ! all PDF members in the given range are
    pdfmemberto=0                ! evaluated (default: no additional sets)

For PDF-uncertainty calculations one can simultaneously calculate additional
cross sections for more than one PDF set if one uses LHAPDF (up to 10 sets
can be used for the prize of doubling the runtime).  The result for the cross
section (including all the corrections) will be written to the specified output
together with the results for the central PDF member. Distributions are only
produced for the central member specified by pdfmember.


# factorization and renormalization scales

    sfactqcd=1                   ! MSbar factorization for QCD (default)
    sfactqcd=2                   ! DIS factorization for QCD

    sfactqed=1                   ! MSbar factorization for QED
    sfactqed=2                   ! DIS factorization for QED (default)

    qcdfacscalefac=1d0           ! multiplicative rescaling of QCD factorization scale
    qcdrenscalefac=1d0           ! multiplicative rescaling of QCD renormalization scale
    qedfacscalefac=1d0           ! multiplicative rescaling of QED factorization scale

with these parameters the factorization and renormalization scales of QCD
and the factorization scale of QED can be rescaled
by default these scales are set to

  *  MW     for  Hjj        (VBFH) (selprocess=0)
  *  MW+MH  for  Hln or Hnl (WH)   (selprocess=1,2)
  *  MZ+MH  for  Hll or Hnn (ZH)   (selprocess=3,4)


# dynamical factorization and renormalization scales

From version 3.0.2 HAWK provides dynamical factorization and renormalization scales with
the following options for the QCD factorization scale

    sqcdfacscale=0               ! fixed factorization scale as above (default)
    sqcdfacscale=1               ! factorization scale = sqrt(ptj1*ptj2)
    sqcdfacscale=2               ! factorization scale = sqrt(mh/2*sqrt((mh/2)^2+ptH^2))
    sqcdfacscale=3               ! factorization scale = sqrt(pV^2+pH^2)

The same options are available for the QCD renormalization scale (sqcdrenscale)
and the QED factorization scale (sqedfacscale). For consistency the same parameters
have to be chosen for the QCD and QED factorization scales.


# switches for LO contributions

    sborn=0    ! tree-level contributions not included
    sborn=1    ! tree-level contributions included (default)


# switches for b-quark contributions

    sbini=1                      ! initial b quarks included
    sbfin=1                      ! final b quarks included

These switches can be used to switch on or off  contributions of b quarks in the
Born contribution.


# switches for contributions to NLO corrections

The following switches can be used to switch on or off various contributions to
the NLO corrections by default all contributions are taken into account (=1)

    sew=0    ! electroweak corrections not included
    sew=1    ! electroweak corrections included (default)

    spinc=0/1       incoming photon contributions ex / included (default)

.. note:

    spinc=1 is only effective if photon-parton distributions are available.

    sqcd=0    ! QCD corrections not included
    sqcd=1    ! QCD corrections included (default)


# extra switches for contributions to NLO corrections for VBFH

    shh2=0      2-loop heavy Higgs corrections excluded
    shh2=1      2-loop heavy Higgs corrections included (default)

.. note::

    These contributions are taken from A. Frink et al.,  Phys. Rev. D 54 (1996)
    4548 [hep-ph/9606310].

.. note::

    This option is not supported with Recola.

Only relevant for VBFH (selprocess = 0):

    sqcddiag=1       ! diagonal QCD corrections included
    sqcdnondiag=1    ! non-diagonal QCD corrections included
    sqcdggfus=1      ! interference with gluon fusion contributions included
    sqcdgsplit=1     ! interference with gluon-splitting contributions included

Switches for QCD subcontributions :

*   only relevant for VBFH (selprocess = 0)

    sqcddiag=0/1     ! diagonal QCD corrections ex/included
    sqcdnondiag=0/1  ! non-diagonal QCD corrections ex/included
    sqcdggfus=0/1    ! interference with gluon fusion contributions ex/included
    sqcdgsplit=0/1   ! interference with gluon-splitting contributions ex/included

.. note::

    The precise definition of these contributions can be found in [2].
      * sch2=0: the diagonal QCD corrections are always excluded,
                 i.e. sqcddiag has no effect.
      * schint=0: the non-diagonal QCD corrections and the interferences
                 with gluon fusion and gluon-splitting are always excluded,
                 i.e. sqcdnondiag, sqcdggfus, and sqcdgsplit have no effect.
      * shvv>0: sqcdnondiag, sqcdggfus, sqcdgsplit are set to zero,
                 these contributions are not supported for anomalous
                 Higgs couplings.

.. note::

    These options are not supported with Recola.

# switches for s/t channels, interferences only for VBFH

    sscha=1                      ! s-channel contributions included
    stcha=1                      ! t/u-channel contributions included
    sch2=1                       ! squared diagrams included
    schint=1                     ! interferences included

These switches can be used to switch on or off  contributions connected to s or
t channel diagrams, squared diagrams or interferences by default all are equal
to 1

.. note::

    To take only squared t-channel (and u-channel) diagrams into account use:
    * sscha=0                      ! s-channel contributions not included
    * stcha=1                      ! t/u-channel contributions included
    * sch2=1                       ! squared diagrams included
    * schint=0                     ! interferences not included
    QCD contributions are in addition steered by the switches sqcddiag,
    sqcdnondiag, sqcdggfus, and sqcdgsplit

.. note::

    These options are not supported with Recola.

Only relevant for VBFH (selprocess = 0), values are automatically set for WH/ZH
(selprocess = 1,2,3,4).

# input for anomalous HVV couplings

Optional inclusion of anomalous HVV couplings (V=W,Z):

    shvv=0  ! no anomalous HVV couplings (default)
    shvv=1  ! inclusion of anomalous HVV couplings
            ! following the (modified) parametrization of
            ! Hankele, Klamke, Zeppenfeld, Figy, hep-ph/0609075
            ! -> input on parameters d, db, dt, dtb expected (default=0d0)
            !    added: input parameter rsm rescales SM HVV coupling (default=1d0)

Detailed setting of HVV couplings (called g_... in hep-ph/0609075):

     a1hww = mw/sw*rsm                      = SM HWW coupling
     a2hww = 2d0*d /sw/mw                   = 2*g^(2)_HWW
     a3hww = 2d0*dt/sw/mw                   = 2*gtilde^(2)_HWW
     a1haa = 0d0                            = HAA like HZZ in SM
     a2haa = 4d0*(d *sw2+db *cw2)/2d0/sw/mw = 4*g_HAA
     a3haa = 4d0*(dt*sw2+dtb*cw2)/2d0/sw/mw = 4*gtilde_HAA
     a1haz = 0d0                            = HZA like HZZ in SM
     a2haz = -2d0*cw*(d -db )/mw            = 2*g^(2)_HZA
             ! sign change in a2haz !
     a3haz = -2d0*cw*(dt-dtb)/mw            = 2*gtilde^(2)_HZA
             ! sign change in a3haz !
     a1hzz = mw/sw/cw2*rsm                  = SM HZZ coupling
     a2hzz = 4d0*(d *cw2+db *sw2)/2d0/sw/mw = 4*g^(2)_HZZ
     a3hzz = 4d0*(dt*cw2+dtb*sw2)/2d0/sw/mw = 4*gtilde_HZZ

 .. note::

    Two sign changes due to our conventions of SM couplings which follow

      * Bohm/Hollik/Spiesberger, Fortsch.Phys.34 (1986) 687
      * Denner, arXiv:0709.1075, Fortsch.Phys.41 (1993) 307

    Feynman rule for HV1(k1_mu)V2(k2_nu):
        i*a1hvv*g_{munu}
      + i*a2hvv*(-k1.k2*g_{munu}+k1_nu*k2_mu)
      + i*a3hvv*eps_{k1k2munu}


    shvv=2   ! direct input for a1hww, ..., a3hzz expected

..  note::

    The anomalous couplings to the neutral gauge bosons are switched off for
    small momentum transfer with a form factor |s1| |s2| / ( m0**2 + |s1| )
    / ( m0**2 + |s2| ) to avoid IR singularities from anomalous couplings m0
    is fixed to m0=1d0

.. note::

    If shvv>0, sqcdnondiag, sqcdggfus, sqcdgsplit are set to zero, these
    contributions are not supported for anomalous Higgs couplings.

    rsm=1d0                      ! rescaling factor of SM HVV coupling
    d=0.00d0                     ! parameter d from hep-ph/0609075
    db=0.00d0                    ! parameter d_b from hep-ph/0609075
    dt=0.00d0                    ! parameter tilde d from hep-ph/0609075
    dtb=0.00d0                   ! parameter tilde d_b from hep-ph/0609075
    lambdahvv=-2d0               ! mass scale in form factor for anomalous couplings

    lambdahvv>0  ! rescaling of HVV couplings by
                 ! form factor = lambdahvv^4 / ( lambdahvv^2 + |s1| )
                 !                           / ( lambdahvv^2 + |s2| )
                 ! s1,s2 = virtualities of the two intermediate W,Z
    lambdahvv<0  ! form factor = 1   (formal limit lambdahvv -> infinity)

.. note::

    Anomalous couplings are not yet supported by Recola.

# technical parameters for Monte Carlo

    ranluxseed=0                 ! default initialization of random number generator

Choosing different positive integers yields different random number seeds.


# parameters steering the output

    lnoutmc=1   ! standard output of montecarlo (default)
    lnoutmc=3   ! intermediate output of montecarlo
    lnoutmc=5   ! full output of montecarlo

    shisto=1    ! histograms are produced (default)
    shisto=0    ! no histograms are produced

.. note::

    By default the following numbers of histograms are included

    * Hjj: 10 + 2 for off-shell Higgs
    * Hln: 11 + 2 for off-shell Higgs
    * Hnl: 11 + 2 for off-shell Higgs
    * Hll: 12 + 2 for off-shell Higgs
    * Hnn:  7 + 2 for off-shell Higgs

    Additional histograms can be implemented by adapting the subroutines
    "settings_Hjj" in "vbfh_public.f" or the subroutines "settings_Hll",
    "settings_Hlv", "settings_Hvl", or "settings_Hvv" in "whzh_public.f"


OUTPUT

By default, all output is written to standard output.
An "outputfile" can however be specified in the inputfile.
The result for the total cross section can be found under
"Summary of results":
            Born cross section:   LO
        complete cross section:   LO + NLO EW + NLO QCD
    QCD corr. to cross section:   NLO QCD = virt. QCD + real QCD + inc. gluon
  incoming gluon cross section:   inc. gluon
   virt+real QCD cross section:   virt. QCD + real QCD
       virt. QCD cross section:   virt. QCD
  outgoing gluon cross section:   real QCD
     ew corr. to cross section:   NLO EW  = virt. EW  + real EW + inc. photon
 incoming photon cross section:   inc. photon
    virt+real ew cross section:   virt. EW  + real EW
        virt. ew cross section:   virt. EW
 outgoing photon cross section:   real EW


For "shisto=1", the program produces a set of histograms:

*******************************************************************************
*     selprocess = 0     Hjj     p p -> jet jet H    (VBFH)
*******************************************************************************
dat.pth           distribution in transverse momentum of Higgs
dat.yh            distribution in rapidity of Higgs
dat.etah          distribution in pseudorapidity of Higgs

distributions of jets:

dat.ptjmax1pt     distribution in transverse momentum of leading jet
dat.ptjmax2pt     distribution in transverse momentum of subleading jet
dat.yjmax1pt      distribution in rapidity of leading jet
dat.yjmax2pt      distribution in rapidity of subleading jet
dat.dyjjmaxpt     distribution in rapidity difference of jets
dat.dphijjmaxpt   distribution in azimuthal angle difference of leading jets
dat.mjjmaxpt      distribution in invariant mass of leading jets

for shtr>0 in addition:

dat.mh            distribution in invariant mass of off-shell Higgs boson
dat.mhwide        distribution in invariant mass of off-shell Higgs boson

*******************************************************************************
*     selprocess = 1     Hlv     p p -> l+  nu  H    (W+H)
*******************************************************************************
dat.pth           distribution in transverse momentum of Higgs
dat.yh            distribution in rapidity of Higgs
dat.etah          distribution in pseudorapidity of Higgs

distributions of W+ boson:

dat.ptv           distribution in transverse momentum of W+

distributions of leptons:

dat.ptlp          distribution in transverse momentum of l+
dat.ylp           distribution in rapidity of l+
dat.etalp         distribution in pseudo-rapidity of l+
dat.ptmiss        distribution in transverse momentum of nu (= ptmiss)
dat.ymiss         distribution in rapidity of nu
dat.etamiss       distribution in pseudo-rapidity of nu

dat.dphilpH       distribution in azimuthal angle difference of l+ and Higgs

for shtr>0 in addition:

dat.mh            distribution in invariant mass of off-shell Higgs boson
dat.mhwide        distribution in invariant mass of off-shell Higgs boson

*******************************************************************************
*     selprocess = 2     Hvl     p p -> l+  nu  H    (W+H)
*******************************************************************************
dat.pth           distribution in transverse momentum of Higgs
dat.yh            distribution in rapidity of Higgs
dat.etah          distribution in pseudorapidity of Higgs

distributions of W- boson:

dat.ptv           distribution in transverse momentum of W-

distributions of leptons:

dat.ptlm          distribution in transverse momentum of l-
dat.ylm           distribution in rapidity of l-
dat.etalm         distribution in pseudo-rapidity of l-
dat.ptmiss        distribution in transverse momentum of nu~ (= ptmiss)
dat.ymiss         distribution in rapidity of nu~
dat.etamiss       distribution in pseudo-rapidity of nu~

dat.dphilmH       distribution in azimuthal angle difference of l- and Higgs

for shtr>0 in addition:

dat.mh            distribution in invariant mass of off-shell Higgs boson
dat.mhwide        distribution in invariant mass of off-shell Higgs boson

*******************************************************************************
*     selprocess = 3     Hll     p p -> l+  l-  H    (ZH)
*******************************************************************************
dat.pth           distribution in transverse momentum of Higgs
dat.yh            distribution in rapidity of Higgs
dat.etah          distribution in pseudorapidity of Higgs

distributions of Z boson:

dat.ptv           distribution in transverse momentum of Z

distributions of leptons:

dat.ptlp          distribution in transverse momentum of l+
dat.ylp           distribution in rapidity of l+
dat.etalp         distribution in pseudo-rapidity of l+
dat.ptlm          distribution in transverse momentum of l-
dat.ylm           distribution in rapidity of l-
dat.etalm         distribution in pseudo-rapidity of l-

dat.dphilpH       distribution in azimuthal angle difference of l+ and Higgs
dat.dphilmH       distribution in azimuthal angle difference of l- and Higgs

for shtr>0 in addition:

dat.mh            distribution in invariant mass of off-shell Higgs boson
dat.mhwide        distribution in invariant mass of off-shell Higgs boson

*******************************************************************************
*     selprocess = 4     Hvv     p p -> nu~ nu  H    (ZH)
*******************************************************************************
dat.pth           distribution in transverse momentum of Higgs
dat.yh            distribution in rapidity of Higgs
dat.etah          distribution in pseudorapidity of Higgs

distributions of Z boson:

dat.ptv           distribution in transverse momentum of Z

distributions of leptons:

dat.ptmiss        distribution in transverse momentum of (nu + nu~) (= ptmiss)
dat.ymiss         distribution in rapidity of Z = (nu + nu~)
dat.etamiss       distribution in pseudo-rapidity of Z = (nu + nu~)

for shtr>0 in addition:

dat.mh            distribution in invariant mass of off-shell Higgs boson
dat.mhwide        distribution in invariant mass of off-shell Higgs boson

*******************************************************************************

These histograms can be adapted, and other histograms can be included
by modifying the respective subroutine "settings_Hxx" in "vbfh_public.F" or
"whzh_public.F", respectively.

For the histograms in Phys.Rev.D77:013002,2008 [arXiv:0710.4749]
10^9 events were used and the histograms rebinned to 20 bins.


COMMENTS

The virtual electroweak corrections are only calculated for each
100th event, the real electroweak contributions only for each 10th event.

Electromagnetic coupling constant:

 The electromagnetic coupling constant is derived from the Fermi constant.
 This procedure takes into account some higher-order effects already at
 tree level.

Treatment of gauge-boson resonances:

 Gauge-boson resonances are treated using the complex-mass scheme.
 (A. Denner, S. Dittmaier, M. Roth, L.H. Wieders,
  Nucl.Phys.B724:247-294,2005, hep-ph/0505042)
 The program reads the on-shell masses and widths and translates
 them internally to the pole masses and widths. These are then used
 in propagators and the complex weak mixing angle and other couplings.

Parallel implementation using the mpi standard:

 HAWK also supports parallel execution using mpi. To use the parallel
 version configure with -DMPI=On. In addition you have to make sure that
 the mpi libraries are properly linked. The parallel version of HAWK has
 been tested using openmpi 1.10.4. Using HAWK with MPI, the input cannot
 be provided via standard input (./hawk-3.0.2 < inputfile) but has to be
 put into a file with the literal name 'inputfile' in the directory of
 the hawk-3.0.2 executable.


## Parameters for extended Higgs sectors

HAWK + Recola2 allows to compute the before-mentioned Higgs production mechanism
in extended Higgs sectors, i.e. for neutral Higgs production in the
Two-Higgs-doublet model and the Higgs-singlet extension of the Standard Model.
All our conventions agree with the ones used in the main text of arXiv:1808.03466.

Set the external Higgs flavour, depending on the Recola2 model in use:

    higgsflavor="H"    ! SM Higgs boson: SM (default)
    higgsflavor="Hl"   ! light Higgs boson: THDM, HSESM (default)
    higgsflavor="Hh"   ! heavy Higgs boson: THDM, HSESM
    higgsflavor="Ha"   ! pseudo scalar Higgs boson: THDM

The Higgs boson masses are set as follows:

    mhh=200.0d0        ! heavy Higgs mass
    mha=200.0d0        ! pseudo scalar Higgs mass
    mhc=200.0d0        ! charged Higgs mass

The light Higgs boson mass is set via ``mh``. Note that ``Hh`` can still be
considered the SM-like Higgs boson, e.g. ``mhh=125GeV`` and ``mhh>mh``.

Set the mixing angles:

    cab = 0.1d0   | THDM
    tb  = 1d0     ! THDM
    l5  = -1.9d0  ! THDM

    sa  = 0.29d0 ! HSESM
    l3  = 0.14d0 ! HSESM

The Yukawa type in the THDM is set by default to type II, but since only the top
quark is considered massive all types are equivalent.

Set the mixing angle renormalization scheme:

    mixrs = 'FJ'   ! THDM,HSESM
    mixrs = 'PR'   ! THDM,HSESM
    mixrs = 'OS'   ! HSESM (default)
    mixrs = 'OS1'  ! THDM
    mixrs = 'OS2'  ! THDM
    mixrs = 'OS12' ! THDM (default)
    mixrs = 'BFM'  ! THDM,HSESM

.. note::

    The Background-Field renormalization schemes can be used also in models not
    formulated with the Background-Field method.

The MSbar schemes (FJ,PR) depend on the BSM MSbar scale:

    mumsbsm = 100d0    ! Sets BSM MSbar scale to 100 GeV

This defines the scale mumsbsm corresponding to the input values for
the parameters sa(mumsbsm), l3(mumsbsm) in the HSESM and
cab(mumsbsm), tb(mumsbsm), l5(mumsbsm) in the THDM.
The default values are
    mumsbsm = (mh + mhh + 2*mhc + mha)/5   in the THDM
    mumsbsm = mh                           in the HSESM

.. note::

    The OS scheme in the HSESM has a scale dependence due to the MSbar
    renormalization of l3 which enters, however, only through the conversion
    and running.


## Conversion and running

HAWK + Recola2 comes with tools to convert between different renormalization
schemes and to compute the running parameters:

  * conv_hs, run_hs: conversion and running tools for the HSESM
  * conv_thdm, run_thdm: conversion and running tools for the THDM

The tools corresponding to the selected model file are automically installed
along with HAWK executable and example input files can be found in
the install path in the examples directory.

### conv_hs

This tool computes the conversion for the HSESM. It expects a parameter card
with at least 5 parameters:

    MHH sa l3 rs_ref rs_cmp

where MHH is the mass of the heavy Higgs boson, sa is the mixing angle.
rs_ref represents the input scheme and rs_cmp is the output scheme.
rs_ref/rs_cmp can take the values ``PR,FJ,OS,BFM``

Example:

    ./conv_hs < pcard

where pcard contains the lines

    MHH=200d0
    sa=0.29d0
    l3=0.14d0
    rs_ref=OS
    rs_cmp=PR

The conversion scale is set to 125d0 by default, but can be overwritten
specifying mumsbsm.

### run_hs

This tool expects 5 arguments:

    MHH sa l3 scalefac rs

where MHH is the mass of the heavy Higgs boson, sa is the mixing angle, and l3 a
Higgs coupling. rs represents the input scheme and scalefac sets the window
for scale variation to [\mu/scalefac, \mu*scalefac]. rs can take the values
``PR,FJ,OS`` which defines the renormalization scheme for ``sa`` (``l3`` is
always renormalized MSbar).
For ``OS`` only the running in ``l3`` is performed.
run_hs writes out the running values in tabular to files (``run_*``) which allow
to extract intermediate values.

Example:

    ./run_hs < pcard

where pcard contains the lines

    MHH=200d0
    sa=0.30216737262974d0
    l3=0.14626363065762d0
    scalefac=2
    rs=PR

### conv_thdm

This tool expects 8 arguments:

    MHH MHA MHC cab tb l5 rs_ref rs_cmp

where MHH,MHA,MHC are the masses of the heavy, pseudo-scalar and charged Higgs
bosons, cab, tb are the mixing angles. rs_ref represents the input scheme and
rs_cmp is the output scheme. rs_ref/rs_cmp can take the values
``PR,FJ,OS1,OS2,OS12,BFM``.

Example:

    ./conv_thdm < pcard


where pcard contains the lines

    MHH=300d0
    MHA=460d0
    MHC=460d0
    cab=0.1d0
    tb=2.d0
    l5=-1.9d0
    mixrs_ref='OS12'
    mixrs_cmp='PR'

The conversion scale is set to the arithmetic mean (125d0 + mhh + mha + 2*mhc)/5
by default, but can be overwritten specifying mumsbsm.

### run_thdm

This tool expects 8 arguments:

    MHH MHA MHC cab tb l5 scalefac rs

where MHH,MHA,MHC are the masses of the heavy, pseudo-scalar and charged Higgs
bosons, cab, tb are the mixing angles, and l5 a Higgs coupling. rs
represents the input scheme and scalefac sets the window for scale variation to
[\mu/scalefac, \mu*scalefac]. rs can take the values
``PR,FJ`` which defines the renormalization for ``cab`` and ``tb`` (``l5`` is
always renormalized MSbar). Any other value for rs will keep ``cab,tb``
fixed (on-shell/bfm) and only the running in l5 is performed.
run_thdm writes out the running values in tabular to files (``run_*``) which
allows to extract intermediate values.

Example:

    ./run_thdm < pcard


where pcard contains the lines

    MHH=300d0
    MHA=460d0
    MHC=460d0
    cab=0.156d0
    tb=1.92d0
    l5=-1.9d0
    scalefac=2d0
    mixrs='PR'

.. note::

    The Standard Model parameters are hard-coded but can be overwritten by
    specifying the model parameters: Gf,MW,GW,MZ,GZ,MT,MB,MHL.
    To print a list of parameters used by the
    modelfile use printp=1 in the parameter card.
    Note that Gf and the on-shell masses (widths) MW(GW),MZ(GZ) are translated
    to aEW (alpha_em calculated from GF and the gauge-boson masses)
    and pole masses consistent with the use in HAWK.


### Examples from arXiv:1808.03466:

BHM200^+ in PRTS

Conversion input:

    MHH=200d0
    sa=0.29d0
    l3=0.14d0
    mixrs_ref='OS'
    mixrs_cmp='PR'

Output:

    Full conversion from OS to PR
        sa:        0.30216737262974
        ca:        0.95325488664787
        l3:        0.14626363065762
    chires:        0.00000000000000

Running input:

    mhh=200
    sa=0.30216737262974d0
    l3=0.14626363065762d0
    scalefac=2d0
    rs='FJ'

Output:

    sa(mu0/2.00)    0.363192372768216
    l3(mu0/2.00)    0.170767547819326
    sa(2.00 mu0)    0.248483391417851
    l3(2.00 mu0)    0.123538412918940

B1 in PRTS

Conversion input:

    MHH=200d0
    MHA=420d0
    MHC=420d0
    cab=0.3d0
    tb=3.d0
    l5=-2.5746d0
    mixrs_ref=OS12
    mixrs_cmp=PR

Output:

    Full conversion from OS12 to PR
        tb:        2.80192588391454
       cab:        0.19663080092935
    chires:        0.00000000000000

Running input:

    MHH=200d0
    MHA=420d0
    MHC=420d0
    cab=0.19663080092935d0
    tb=2.80192588391454d0
    l5=-2.5746d0
    scalefac=2d0
    rs='PR'

Output:

     tb(mu0/2.00)    2.843353531692580
    cab(mu0/2.00)   -0.062497261937392
     l5(mu0/2.00)   -2.381641449278198
     tb(2.00 mu0)    2.760966977984491
    cab(2.00 mu0)    0.682946535943313
     l5(2.00 mu0)   -2.871632733844993

.. note::

  The results from arXiv:1808.03466 cannot be exactly reproduced
  with the current version due to the change of input parameters and ambiguities
  related to input parameters and the complex mass scheme. Nevertheless the
  differences should be phenomenologically irrelevant for well-behaved benchmark
  scenarios.

SAMPLERUNS

We provide several sample input files along with the corresponding results.
They can be found in the corresponding subdirectories of HAWK-3.0.2/sampleruns.
All sample runs (apart from input_default) use 10^7 events and default
input parameters and cuts for the corresponding processes. They typically
take between 1 hour (testrun.Hnn) to 12 hours (testrun.Hjj_ofs) for the
version without RECOLA. When using RECOLA, the run times increase by up to
a factor 7 (for VBFH).
The histograms of the sample runs are also provided.

* "input_default":
  This file shows all input parameters with their default values and
  provides a run with 10^6 events for VBFH, pp -> Hjj, for on-shell Higgs,
  taking about 1 hour (with the gfortran compiler, or 20 minutes
  using the ifort compiler). The output can be found in "output_default".
  The file "input_sample" is equivalent to "input_default", making use
  of the default settings in HAWK.
  (does not run with RECOLA, since non-zero Cabibbo angle not supported).

* "samplerun.Hjj_default":
  Subdirectory with a sample run for VBFH, pp -> Hjj, for on-shell Higgs
  with the default input parameter set of HAWK-3.0.
  (does not run with RECOLA, since non-zero Cabibbo angle not supported).

* "samplerun.Hmn_default":
  Subdirectory with a sample run for pp -> HW^+ -> H anti-mu nu, for
  bare anti-muon and on-shell Higgs
  with the default input parameter set of HAWK-3.0.

* "samplerun.Hjj":
  Subdirectory with a sample run for VBFH, pp -> Hjj, for on-shell Higgs
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.
  (does not run with RECOLA, since non-zero Cabibbo angle not supported).

* "samplerun.Hjj.no_LHAPDF":
  Subdirectory with a sample run for VBFH, pp -> Hjj, for on-shell Higgs and
  MRST2004QED PDF. No LHAPDF installation is needed for this sample run
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.
  (does not run with RECOLA, since non-zero Cabibbo angle not supported).

* "samplerun.Hjj.ofs":
  Subdirectory with a sample run for VBFH, pp -> Hjj, for off-shell Higgs
  using an off-shell propagator
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.
  (does not run with RECOLA, since off-shell Higgs-boson not supported).

* "samplerun.Hmm":
  Subdirectory with a sample run for pp -> HZ -> H mu^+ mu^-, for
  bare muons and on-shell Higgs
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.

* "samplerun.Hnn":
  Subdirectory with a sample run for pp -> HZ -> H nubar nu, for on-shell Higgs
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.

* "samplerun.Hmn":
  Subdirectory with a sample run for pp -> HW^+ -> H anti-mu nu, for
  bare anti-muon and on-shell Higgs
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.

* "samplerun.Hnm":
  Subdirectory with a sample run for pp -> HW^- -> H anti-nu mu,
  for bare muon and on-shell Higgs
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.

* "samplerun.Hmn.undet_lepton":
  Subdirectory with a sample run for pp -> HW^+ -> H anti-mu nu,
  for on-shell Higgs and undetected bare anti-muon
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.

* "samplerun.Hjj.ac":
  Subdirectory with a sample run for VBFH, pp -> Hjj, for
  on-shell Higgs with anomalous VHH couplings
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.
  (does not run with RECOLA, since anomalous VHH couplings not supported).

* "samplerun.Hmn.ac":
  Subdirectory with a sample run for pp -> HW^+ -> H anti-mu nu, for
  bare anti-muon and on-shell Higgs with anomalous VHH couplings.
  with the parameters of CERN-2011-002 and the setup of CERN-2013-004.
  (does not run with RECOLA, since anomalous VHH couplings not supported).

* "samplerun.Hmn.THDM_A1_OS12":
  Subdirectory with a sample run for pp -> HW^+ -> H anti-mu nu, for
  bare anti-muon and on-shell Higgs in the Two-Higgs-Doublet model
  with the parameters of [4] arXiv:1808.03466.
  (based on RECOLA2).

* "samplerun.Hmn.HSESM_BHM200P_OS":
  Subdirectory with a sample run for pp -> HW^+ -> H anti-mu nu, for
  bare anti-muon and on-shell Higgs in the Higgs-singlet extension of
  with the parameters of [4] arXiv:1808.03466.
  the SM (based on RECOLA2).
