        subroutine compute_photon_radiation(pin, m2i_phot)
          use recola
          use quarklabels
          implicit none
#include "mcinput.h"
          real(kind (23d0)), intent(in) :: pin(6,0:3)
          real(kind (23d0)) :: p(0:3,6), k(0:3,6)
          real(kind (23d0)), intent(inout) :: m2i_phot(-5:5,-5:5)
          real(kind (23d0)) :: matrix2(2),sth,cth
          logical           :: CKM_nondiagonal

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
            sth = sinthetacin
            cth = cos(asin(sinthetacin))
          else
            CKM_nondiagonal = .false.
          end if
          m2i_phot = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          p(:,6) = pin(6,:)
          call compute_process_rcl(4, p, "LO", matrix2)
          m2i_phot(in11,in12) = 36d0*matrix2(1)
          call compute_process_rcl(5, p, "LO", matrix2)
          m2i_phot(in21,in22) = 36d0*matrix2(1)

          ! only ckm non-diagonal
          if (CKM_nondiagonal .and. n_in_states .ne. 4) then
            m2i_phot(in21,in12) = m2i_phot(in11,in12)*sth**2
            m2i_phot(in11,in22) = m2i_phot(in21,in22)*sth**2
            m2i_phot(in11,in12) = m2i_phot(in11,in12)*cth**2
            m2i_phot(in21,in22) = m2i_phot(in21,in22)*cth**2
          end if

          if (n_in_states .eq. 4) then
            call compute_process_rcl(44, p, "LO", matrix2)
            m2i_phot(in31,in32) = 36d0*matrix2(1)
            call compute_process_rcl(45, p, "LO", matrix2)
            m2i_phot(in41,in42) = 36d0*matrix2(1)
          end if

          ! interchange incoming quarks
          k(:,1) = p(:,2)
          k(:,2) = p(:,1)
          k(:,3:) = p(:,3:)
          call compute_process_rcl(4, k, "LO", matrix2)
          m2i_phot(in12, in11) = 36d0*matrix2(1)
          call compute_process_rcl(5, k, "LO", matrix2)
          m2i_phot(in22,in21) = 36d0*matrix2(1)

          ! only for non-diagonal CKM
          if (CKM_nondiagonal .and. n_in_states .ne. 4) then
            m2i_phot(in12,in21) = m2i_phot(in12,in11)*sth**2
            m2i_phot(in22,in11) = m2i_phot(in22,in21)*sth**2
            m2i_phot(in12,in11) = m2i_phot(in12,in11)*cth**2
            m2i_phot(in22,in21) = m2i_phot(in22,in21)*cth**2
          end if

          if (n_in_states .eq. 4) then
            call compute_process_rcl(44, k, "LO", matrix2)
            m2i_phot(in32,in31) = 36d0*matrix2(1)
            call compute_process_rcl(45, k, "LO", matrix2)
            m2i_phot(in42,in41) = 36d0*matrix2(1)
          end if
        end subroutine compute_photon_radiation

        subroutine compute_gluon_radiation(pin, m2i_gluon)
          use recola
          use quarklabels
          implicit none
#include "mcinput.h"
          real(kind (23d0)), intent(in) :: pin(6,0:3)
          real(kind (23d0)) :: p(0:3,6), k(0:3,6)
          real(kind (23d0)), intent(inout) :: m2i_gluon(-5:5,-5:5)
          real(kind (23d0)) :: matrix2(2),sth,cth
          logical           :: CKM_nondiagonal

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
            sth = sinthetacin
            cth = cos(asin(sinthetacin))
          else
            CKM_nondiagonal = .false.
          end if

          m2i_gluon = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          p(:,6) = pin(6,:)
          call compute_process_rcl(8, p, "LO", matrix2)
          m2i_gluon(in11,in12) = 36d0*matrix2(1)
          call compute_process_rcl(9, p, "LO", matrix2)
          m2i_gluon(in21,in22) = 36d0*matrix2(1)

          ! only ckm non-diagonal
          if (CKM_nondiagonal .and. n_in_states .ne. 4) then
            m2i_gluon(in21,in12) = m2i_gluon(in11,in12)*sth**2
            m2i_gluon(in11,in22) = m2i_gluon(in21,in22)*sth**2
            m2i_gluon(in11,in12) = m2i_gluon(in11,in12)*cth**2
            m2i_gluon(in21,in22) = m2i_gluon(in21,in22)*cth**2
          end if

          if (n_in_states .eq. 4) then
            call compute_process_rcl(48, p, "LO", matrix2)
            m2i_gluon(in31,in32) = 36d0*matrix2(1)
            call compute_process_rcl(49, p, "LO", matrix2)
            m2i_gluon(in41,in42) = 36d0*matrix2(1)
          end if

          ! interchange incoming quarks
          k(:,1) = p(:,2)
          k(:,2) = p(:,1)
          k(:,3:) = p(:,3:)
          call compute_process_rcl(8, k, "LO", matrix2)
          m2i_gluon(in12,in11) = 36d0*matrix2(1)
          call compute_process_rcl(9, k, "LO", matrix2)
          m2i_gluon(in22,in21) = 36d0*matrix2(1)

          ! only for non-diagonal CKM
          if (CKM_nondiagonal .and. n_in_states .ne. 4) then
            m2i_gluon(in12,in21) = m2i_gluon(in12,in11)*sth**2
            m2i_gluon(in22,in11) = m2i_gluon(in22,in21)*sth**2
            m2i_gluon(in12,in11) = m2i_gluon(in12,in11)*cth**2
            m2i_gluon(in22,in21) = m2i_gluon(in22,in21)*cth**2
          end if

          if (n_in_states .eq. 4) then
            call compute_process_rcl(48, k, "LO", matrix2)
            m2i_gluon(in32,in31) = 36d0*matrix2(1)
            call compute_process_rcl(49, k, "LO", matrix2)
            m2i_gluon(in42,in41) = 36d0*matrix2(1)
          end if
        end subroutine compute_gluon_radiation

        subroutine compute_photon_induced1_rcl(pin, m2i_phot)
          use recola
          use quarklabels
          implicit none
#include "mcinput.h"
          real(kind (23d0)), intent(in) :: pin(6,0:3)
          real(kind (23d0)) :: p(0:3,6), k(0:3,6)
          real(kind (23d0)), intent(inout) :: m2i_phot(-5:5)
          real(kind (23d0)) :: matrix2(2)
          logical           :: CKM_nondiagonal

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
          else
            CKM_nondiagonal = .false.
          end if

          m2i_phot = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          p(:,6) = pin(6,:)
          call compute_process_rcl(10, p, "LO", matrix2)
          m2i_phot(in12) = 12d0*matrix2(1)
          call compute_process_rcl(11, p, "LO", matrix2)
          m2i_phot(in22) = 12d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(50, p, "LO", matrix2)
            m2i_phot(in32) = 12d0*matrix2(1)
            call compute_process_rcl(51, p, "LO", matrix2)
            m2i_phot(in42) = 12d0*matrix2(1)
          end if

          ! interchange incoming quarks
          k(:,1) = p(:,2)
          k(:,2) = p(:,1)
          k(:,3:) = p(:,3:)
          call compute_process_rcl(14, k, "LO", matrix2)
          m2i_phot(in11) = 12d0*matrix2(1)
          call compute_process_rcl(15, k, "LO", matrix2)
          m2i_phot(in21) = 12d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(54, k, "LO", matrix2)
            m2i_phot(in31) = 12d0*matrix2(1)
            call compute_process_rcl(55, k, "LO", matrix2)
            m2i_phot(in41) = 12d0*matrix2(1)
          end if
        end subroutine compute_photon_induced1_rcl

        subroutine compute_photon_induced2(pin, m2i_phot)
          use recola
          use quarklabels
          implicit none
#include "mcinput.h"
          real(kind (23d0)), intent(in) :: pin(6,0:3)
          real(kind (23d0)) :: p(0:3,6), k(0:3,6)
          real(kind (23d0)), intent(inout) :: m2i_phot(-5:5)
          real(kind (23d0)) :: matrix2(2)
          logical           :: CKM_nondiagonal

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
          else
            CKM_nondiagonal = .false.
          end if

          m2i_phot = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          p(:,6) = pin(6,:)
          call compute_process_rcl(14, p, "LO", matrix2)
          m2i_phot(in11) = 12d0*matrix2(1)
          call compute_process_rcl(15, p, "LO", matrix2)
          m2i_phot(in21) = 12d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(54, p, "LO", matrix2)
            m2i_phot(in31) = 12d0*matrix2(1)
            call compute_process_rcl(55, p, "LO", matrix2)
            m2i_phot(in41) = 12d0*matrix2(1)
          end if

          ! interchange incoming quarks
          k(:,1) = p(:,2)
          k(:,2) = p(:,1)
          k(:,3:) = p(:,3:)
          call compute_process_rcl(10, k, "LO", matrix2)
          m2i_phot(in12) = 12d0*matrix2(1)
          call compute_process_rcl(11, k, "LO", matrix2)
          m2i_phot(in22) = 12d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(50, k, "LO", matrix2)
            m2i_phot(in32) = 12d0*matrix2(1)
            call compute_process_rcl(51, k, "LO", matrix2)
            m2i_phot(in42) = 12d0*matrix2(1)
          end if
        end subroutine compute_photon_induced2

        subroutine compute_gluon_induced1(pin, m2i_gluon)
          use recola
          use quarklabels
          implicit none
#include "mcinput.h"
          real(kind (23d0)), intent(in) :: pin(6,0:3)
          real(kind (23d0)) :: p(0:3,6), k(0:3,6)
          real(kind (23d0)), intent(inout) :: m2i_gluon(-5:5)
          real(kind (23d0)) :: matrix2(2)
          logical           :: CKM_nondiagonal

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
          else
            CKM_nondiagonal = .false.
          end if
          m2i_gluon = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          p(:,6) = pin(6,:)
          call compute_process_rcl(18, p, "LO", matrix2)
          m2i_gluon(in12) = 96d0*matrix2(1)
          call compute_process_rcl(19, p, "LO", matrix2)
          m2i_gluon(in22) = 96d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(58, p, "LO", matrix2)
            m2i_gluon(in32) = 96d0*matrix2(1)
            call compute_process_rcl(59, p, "LO", matrix2)
            m2i_gluon(in42) = 96d0*matrix2(1)
          end if

          ! interchange incoming quarks
          k(:,1) = p(:,2)
          k(:,2) = p(:,1)
          k(:,3:) = p(:,3:)
          call compute_process_rcl(22, k, "LO", matrix2)
          m2i_gluon(in11) = 96d0*matrix2(1)
          call compute_process_rcl(23, k, "LO", matrix2)
          m2i_gluon(in21) = 96d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(62, k, "LO", matrix2)
            m2i_gluon(in31) = 96d0*matrix2(1)
            call compute_process_rcl(63, k, "LO", matrix2)
            m2i_gluon(in41) = 96d0*matrix2(1)
          end if
        end subroutine compute_gluon_induced1

        subroutine compute_gluon_induced2(pin, m2i_gluon)
          use recola
          use quarklabels
          implicit none
#include "mcinput.h"
          real(kind (23d0)), intent(in) :: pin(6,0:3)
          real(kind (23d0)) :: p(0:3,6), k(0:3,6)
          real(kind (23d0)), intent(inout) :: m2i_gluon(-5:5)
          real(kind (23d0)) :: matrix2(2)
          logical           :: CKM_nondiagonal

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
          else
            CKM_nondiagonal = .false.
          end if

          m2i_gluon = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          p(:,6) = pin(6,:)
          call compute_process_rcl(22, p, "LO", matrix2)
          m2i_gluon(in11) = 96d0*matrix2(1)
          call compute_process_rcl(23, p, "LO", matrix2)
          m2i_gluon(in21) = 96d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(62, p, "LO", matrix2)
            m2i_gluon(in31) = 96d0*matrix2(1)
            call compute_process_rcl(63, p, "LO", matrix2)
            m2i_gluon(in41) = 96d0*matrix2(1)
          end if

          ! interchange incoming quarks
          k(:,1) = p(:,2)
          k(:,2) = p(:,1)
          k(:,3:) = p(:,3:)
          call compute_process_rcl(18, k, "LO", matrix2)
          m2i_gluon(in12) = 96d0*matrix2(1)
          call compute_process_rcl(19, k, "LO", matrix2)
          m2i_gluon(in22) = 96d0*matrix2(1)

          if (n_in_states .eq. 4) then
            call compute_process_rcl(58, k, "LO", matrix2)
            m2i_gluon(in32) = 96d0*matrix2(1)
            call compute_process_rcl(59, k, "LO", matrix2)
            m2i_gluon(in42) = 96d0*matrix2(1)
          end if
        end subroutine compute_gluon_induced2

        subroutine compute_lepton_in2_rcl(selprocess,pin,m2i0)
          use recola, only: compute_process_rcl
          use quarklabels
          implicit none
#include "mcinput.h"
          integer, intent(in) :: selprocess
          real(kind (23d0)), intent(in) :: pin(5,0:3)
          real(kind (23d0)) :: p(0:3,5), k(0:3,5)
          real(kind (23d0)), intent(inout) :: m2i0(-5:5,-5:5)
          real(kind (23d0)) :: matrix2(2)
          logical           :: CKM_nondiagonal
          integer :: j

          if (sinthetacin .ne. 0d0) then
            CKM_nondiagonal = .true.
          else
            CKM_nondiagonal = .false.
          end if

          m2i0 = 0d0
          p(:,1) = pin(1,:)
          p(:,2) = pin(2,:)
          p(:,3) = pin(3,:)
          p(:,4) = pin(4,:)
          p(:,5) = pin(5,:)
          if (n_in_states .eq. 2) then
          if (selprocess .eq. 1) then
            j = -2
          else
            j = -1
          end if
          call compute_process_rcl(411, p, "LO", matrix2)
          m2i0(in11,j) = 12d0*matrix2(1)
          m2i0(in21,j) = 12d0*matrix2(1)

          call compute_process_rcl(412, p, "LO", matrix2)
          m2i0(in12,j) = 12d0*matrix2(1)
          m2i0(in22,j) = 12d0*matrix2(1)

          if (selprocess .eq. 1) then
            j = 1
          else
            j = 2
          end if
          call compute_process_rcl(413, p, "LO", matrix2)
          m2i0(in12,j) = 12d0*matrix2(1)
          m2i0(in22,j) = 12d0*matrix2(1)

          call compute_process_rcl(414, p, "LO", matrix2)
          m2i0(in11,j) = 12d0*matrix2(1)
          m2i0(in21,j) = 12d0*matrix2(1)
          end if

          if (n_in_states .eq. 4) then
            j = 1
          call compute_process_rcl(400, p, "LO", matrix2)
          m2i0(in21,j) = 12d0*matrix2(1)
          call compute_process_rcl(401, p, "LO", matrix2)
          m2i0(in11,j) = 12d0*matrix2(1)
          call compute_process_rcl(403, p, "LO", matrix2)
          m2i0(in21,-j) = 12d0*matrix2(1)
          call compute_process_rcl(404, p, "LO", matrix2)
          m2i0(in11,-j) = 12d0*matrix2(1)

          call compute_process_rcl(410, p, "LO", matrix2)
          m2i0(in22,j) = 12d0*matrix2(1)
          call compute_process_rcl(411, p, "LO", matrix2)
          m2i0(in21,j) = 12d0*matrix2(1)
          call compute_process_rcl(413, p, "LO", matrix2)
          m2i0(in22,-j) = 12d0*matrix2(1)
          call compute_process_rcl(414, p, "LO", matrix2)
          m2i0(in21,-j) = 12d0*matrix2(1)
          end if
          
        end subroutine compute_lepton_in2_rcl
