program s
  use input_mdl
  use modelfile
  use class_particles
  use pde_integrator, only: rk4_step, euler_step, update_func, set_kernel
  implicit none

  character(len=4) :: renoscheme = ''
  complex(kind=kind(23d0)) :: t,Gf,minv,minmh2,minmsb2
  integer :: i,j
  procedure (update_func), pointer :: reset_func
  procedure (set_kernel), pointer  :: set_k

  integer, parameter :: steps = 800
  real(kind=kind(23d0)), parameter :: scale_init = 100d0, scale_fac = 2d0
  real(kind=kind(23d0)), dimension(-steps:steps) :: scale_arr, alphas_arr


  character(len=4) :: benchmarkpoint = 'SM'
  character(len=100) :: file_bp
  character(len=*), parameter :: fmt = '(e21.14,x,e21.14)'

  renoscheme = 'Nf6'
  reset_func => reset_alphas
  set_k => set_beta_alphas

  call init_param
  call reset_alphas
  call running(scale_init,scale_init/scale_fac)
  call init_param
  call reset_alphas
  call running(scale_init,scale_init*scale_fac)

  file_bp = trim(benchmarkpoint) // '_' // trim(renoscheme) // '_alphas'
  open(unit=1,file=trim(file_bp),status='replace',position='append')


  do i = -steps, steps
    write(1,fmt) scale_arr(i), alphas_arr(i)
  end do

  close(1)

  contains  

  subroutine init_param_sm()
    ME = 0d0
    MM = 0d0
    MTA = 0d0
    MC = 0d0
    MB = 0d0
    MD = 0d0
    MS = 0d0
    MU = 0d0
    MT = 173.21d0
    MHL = 125.09d0
    MW = 8.0357973609878002d+01
    MZ = 9.1153480619179007d+01
    WW = 2.0842989982782d0
    WT = 0d0
    WZ = 2.4942663787728d0
    Gf = 0.11663800000000d-04
    muUV = MHL
    muMS = MHL
    aEW = Gf/pi*MW**2d0*(1d0-MW**2d0/MZ**2d0)* &
          sqrt(2d0)*complex(1d0,0d0)

    
    muUV = 80.357973609878d0
    muIR = 80.357973609878d0
    muMS = 100d0
    call set_parameter_mdl("MHL",complex(125d0, 0d0))
    call set_parameter_mdl("WHC",complex(0d0, 0d0))
    call set_parameter_mdl("h2u",complex(1d0, 0d0))
    call set_parameter_mdl("WT",complex(0d0, 0d0))
    call set_parameter_mdl("WTA",complex(0d0, 0d0))
    call set_parameter_mdl("WM",complex(0d0, 0d0))
    call set_parameter_mdl("WC",complex(0d0, 0d0))
    call set_parameter_mdl("WB",complex(0d0, 0d0))
    call set_parameter_mdl("h2l",complex(0d0, 0d0))
    call set_parameter_mdl("h1u",complex(0d0, 0d0))
    call set_parameter_mdl("MHH",complex(400d0, 0d0))
    call set_parameter_mdl("WHA",complex(0d0, 0d0))
    call set_parameter_mdl("ME",complex(ME, 0d0))
    call set_parameter_mdl("MD",complex(MD, 0d0))
    call set_parameter_mdl("MTA",complex(MTA, 0d0))
    call set_parameter_mdl("aEW",aEW)
    call set_parameter_mdl("MC",complex(MC, 0d0))
    call set_parameter_mdl("MB",complex(MB, 0d0))
    call set_parameter_mdl("WHL",complex(0d0, 0d0))
    call set_parameter_mdl("WHH",complex(0d0, 0d0))
    call set_parameter_mdl("aS",complex(0.1d0, 0d0))
    call set_parameter_mdl("msb",complex(111d0, 0d0))
    call set_parameter_mdl("MU",complex(MU, 0d0))
    call set_parameter_mdl("MT",complex(MT, 0d0))
    call set_parameter_mdl("h1l",complex(1d0, 0d0))
    call set_parameter_mdl("MS",complex(MS, 0d0))
    call set_parameter_mdl("cb",complex(7.4329414624716639d-01, 0d0))
    call set_parameter_mdl("h2d",complex(0d0, 0d0))
    call set_parameter_mdl("sa",complex(-1.9325647802426335d-01, 0d0))
    call set_parameter_mdl("h1d",complex(1d0, 0d0))
    call set_parameter_mdl("MM",complex(MM, 0d0))
    
  end subroutine init_param_sm

  subroutine init_param
    use scalar_functions
    complex(dp), allocatable :: m2(:)
    real(dp) :: cab_in,tb_in,mhh_in,mha_in,mhc_in,msb_in,massreg
    integer :: nn

    call init_param_sm

    alphas_arr(0) = aS
    scale_arr(0) = 1d0

    deltaUV = 0d0
    deltaIR = 0d0
    deltaIR2 = 0d0
    masscut = 0d0
    call init_cmasses_mdl()


    !call print_parameters_mdl(2)
    !stop

    call Init_cll(2,noreset=.true.)
    call SetMode_cll(1)
    call SetDeltaUV_cll (deltaUV)
    call SetDeltaIR_cll (deltaIR,deltaIR2)
    call SetMuIR2_cll(muIR**2)
    call SetMuUV2_cll(muUV**2)
    nn = 0
    do i = 1,n_particles
    if (get_particle_mass_reg_mdl(i) .eq. 2 .and. is_particle_mdl(i)) nn = nn + 1
    end do
    allocate (m2(nn))
    nn = 0
    do i = 1,n_particles
    if (get_particle_mass_reg_mdl(i) .eq. 2 .and. is_particle_mdl(i)) then
    nn = nn + 1
    m2(nn) = get_particle_cmass2_reg_mdl(i)
    endif
    enddo
    call setminf2_cll (nn,m2)
    deallocate (m2)

  end subroutine init_param

  subroutine running(scale0,scale)
    real(kind=kind(23d0)), intent(in)    :: scale0,scale
    real(kind=kind(23d0)) :: gs0,gsm
    complex(kind=kind(23d0)),dimension(1) :: y
    real(kind=kind(23d0)) :: scale20,scale2,stepsize,scale2m
    logical :: flat = .false.
    integer :: step

    scale20 = scale0**2d0
    scale2  = scale**2d0
    step = 0

    stepsize = (scale2-scale20)/real(steps,kind=kind(23d0))

    gs0 = sqrt(4*pi*aS)

    write(*,*) "scale0:", scale0
    write(*,*) "aS@scale0:  ", gs0**2/(4*pi)

    call reset_alphas

    scale2m = scale20
    gsm     = gs0
    do while ((scale2m .gt. scale2 .and. stepsize .lt. 0d0) .or. &
              (scale2m .lt. scale2 .and. stepsize .gt. 0d0))
      y = (/gsm/)
      call rk4_step(y,scale2m,stepsize,flat,1,reset_func,set_k)
      gsm = y(1)

      aS = gsm**2/(4*pi)
      
      call reset_alphas
      if (stepsize .gt. 0) then
        step = step + 1
      else
        step = step - 1
      end if
      alphas_arr(step) = gsm**2/(4*pi)
      scale_arr(step) = sqrt(scale2m)/scale_init
    end do
    aS = gsm**2/(4*pi)
    
    call reset_alphas

    write(*,*) "scale:", scale
    write(*,*) "aS@scale: ", gsm**2/(4*pi)

  end subroutine running

  subroutine reset_alphas(yc)

    use class_particles, only: aS
    use alphas_ct, only: initct, dZgs_Nf5, dZgs_Nf6
    !use class_particles, only: init_parameters_mdl
    complex(kind=kind(23d0)) :: dZgs_Nf5_tmp
    complex(kind=kind(23d0)), dimension(:), optional, intent(in) :: yc

    if (present(yc)) then
      aS = yc(1)**2/(4*pi)
    endif
    call init_parameters_mdl()
    call initct(1d0)
    if (renoscheme .eq. 'Nf5') then
      dZgs_Nf5_tmp = dZgs_Nf5
      call initct(0d0)
      dZgs_Nf5 = (dZgs_Nf5_tmp - dZgs_Nf5)
    end if

  end subroutine reset_alphas

  subroutine set_beta_alphas(x,f)

    use class_particles
    use alphas_ct, only: dZgs_Nf5, dZgs_Nf6
    real(kind=kind(23d0)),                  intent(in)  :: x
    complex(kind=kind(23d0)), dimension(:), intent(out) :: f

    if (renoscheme .eq. 'Nf5') then
      f(:) = (/gs*dZgs_Nf5/x/)
    else if (renoscheme .eq. 'Nf6') then
      f(:) = (/gs*dZgs_Nf6/x/)
    end if

  end subroutine set_beta_alphas

end program s
